@@ -13,9 +13,10 @@ from django.forms.models import model_to_dict
 from django.db.models import Q
 from xj_role.services.role_service import RoleService
 from xj_user.models import BaseInfo
-from xj_user.services.user_service import UserService
 from xj_user.services.user_detail_info_service import DetailInfoService
-from ..models import UserToGroup, RoleUserGroup, UserToRole
+from xj_user.services.user_service import UserService
+# from xj_user.services.user_detail_info_service import DetailInfoService
+from ..models import UserToGroup, RoleUserGroup, UserToRole, Role
 from ..utils.model_handle import format_params_handle, parse_json
 from ..utils.j_recur import JRecur
 
@@ -192,7 +193,7 @@ class UserGroupService(object):
         #     if err:
         #         return None, err
         #     user_serv = user_serv_dict[0]
-        user_serv_dict, err = UserService.user_basic_message(user_id)
+        user_serv_dict, err = DetailInfoService.get_detail(user_id)
         if err:
             return None, err
         user_serv = user_serv_dict
@@ -228,11 +229,11 @@ class UserGroupService(object):
         # 用户角色部门绑定
         user_role_list = params.get('user_role_list', None)
         user_group_list = params.get('user_group_list', None)
-        user_serv, err = UserService.user_role_edit(params)
+        user_serv, err = UserService.user_edit(params, params.get("user_id"))
         if err:
             return None, err
-        UserGroupService.bind_user_group(user_serv['user_id'], user_group_list)
-        RoleService.bind_user_role(user_serv['user_id'], user_role_list)
+        UserGroupService.bind_user_group(params.get("user_id"), user_group_list)
+        RoleService.bind_user_role(params.get("user_id"), user_role_list)
         return user_serv, None
 
     @staticmethod
